@@ -2,7 +2,6 @@
 # Code written by Fatih C Akyon, 2020.
 
 import logging
-import os
 import warnings
 from typing import Dict, List, Optional, Union
 
@@ -10,6 +9,7 @@ import numpy as np
 
 from sahi.prediction import ObjectPrediction
 from sahi.utils.compatibility import fix_full_shape_list, fix_shift_amount_list
+from sahi.utils.cv import get_bbox_from_bool_mask
 from sahi.utils.torch import cuda_is_available, empty_cuda_cache
 
 logger = logging.getLogger(__name__)
@@ -89,7 +89,6 @@ class DetectionModel:
         """
         This function should be implemented in a way that prediction should be
         performed using self.model and the prediction result should be set to self._original_predictions.
-
         Args:
             image: np.ndarray
                 A numpy array that contains the image to be predicted.
@@ -107,7 +106,6 @@ class DetectionModel:
         This function should be implemented in a way that self._original_predictions should
         be converted to a list of prediction.ObjectPrediction and set to
         self._object_prediction_list. self.mask_threshold can also be utilized.
-
         Args:
             shift_amount: list
                 To shift the box and mask predictions from sliced image to full sized image, should be in the form of [shift_x, shift_y]
@@ -137,7 +135,6 @@ class DetectionModel:
         """
         Converts original predictions of the detection model to a list of
         prediction.ObjectPrediction object. Should be called after perform_inference().
-
         Args:
             shift_amount: list
                 To shift the box and mask predictions from sliced image to full sized image, should be in the form of [shift_x, shift_y]
@@ -200,7 +197,6 @@ class MmdetDetectionModel(DetectionModel):
     def perform_inference(self, image: np.ndarray, image_size: int = None):
         """
         Prediction is performed using self.model and the prediction result is set to self._original_predictions.
-
         Args:
             image: np.ndarray
                 A numpy array that contains the image to be predicted. 3 channel image should be in RGB order.
@@ -271,7 +267,6 @@ class MmdetDetectionModel(DetectionModel):
         """
         self._original_predictions is converted to a list of prediction.ObjectPrediction and set to
         self._object_prediction_list_per_image.
-
         Args:
             shift_amount_list: list of list
                 To shift the box and mask predictions from sliced image to full sized image, should
@@ -324,23 +319,21 @@ class MmdetDetectionModel(DetectionModel):
                     else:
                         bool_mask = None
 
+                    # fix negative box coords
+                    bbox[0] = max(0, bbox[0])
+                    bbox[1] = max(0, bbox[1])
+                    bbox[2] = max(0, bbox[2])
+                    bbox[3] = max(0, bbox[3])
+
+                    # fix out of image box coords
+                    if full_shape is not None:
+                        bbox[0] = min(full_shape[1], bbox[0])
+                        bbox[1] = min(full_shape[0], bbox[1])
+                        bbox[2] = min(full_shape[1], bbox[2])
+                        bbox[3] = min(full_shape[0], bbox[3])
+
                     # ignore invalid predictions
-                    if (
-                        bbox[0] > bbox[2]
-                        or bbox[1] > bbox[3]
-                        or bbox[0] < 0
-                        or bbox[1] < 0
-                        or bbox[2] < 0
-                        or bbox[3] < 0
-                    ):
-                        logger.warning(f"ignoring invalid prediction with bbox: {bbox}")
-                        continue
-                    if full_shape is not None and (
-                        bbox[1] > full_shape[0]
-                        or bbox[3] > full_shape[0]
-                        or bbox[0] > full_shape[1]
-                        or bbox[2] > full_shape[1]
-                    ):
+                    if not (bbox[0] < bbox[2]) or not (bbox[1] < bbox[3]):
                         logger.warning(f"ignoring invalid prediction with bbox: {bbox}")
                         continue
 
@@ -384,7 +377,6 @@ class Yolov5DetectionModel(DetectionModel):
     def perform_inference(self, image: np.ndarray, image_size: int = None):
         """
         Prediction is performed using self.model and the prediction result is set to self._original_predictions.
-
         Args:
             image: np.ndarray
                 A numpy array that contains the image to be predicted. 3 channel image should be in RGB order.
@@ -436,7 +428,6 @@ class Yolov5DetectionModel(DetectionModel):
         """
         self._original_predictions is converted to a list of prediction.ObjectPrediction and set to
         self._object_prediction_list_per_image.
-
         Args:
             shift_amount_list: list of list
                 To shift the box and mask predictions from sliced image to full sized image, should
@@ -469,16 +460,21 @@ class Yolov5DetectionModel(DetectionModel):
                 category_id = int(prediction[5])
                 category_name = self.category_mapping[str(category_id)]
 
+                # fix negative box coords
+                bbox[0] = max(0, bbox[0])
+                bbox[1] = max(0, bbox[1])
+                bbox[2] = max(0, bbox[2])
+                bbox[3] = max(0, bbox[3])
+
+                # fix out of image box coords
+                if full_shape is not None:
+                    bbox[0] = min(full_shape[1], bbox[0])
+                    bbox[1] = min(full_shape[0], bbox[1])
+                    bbox[2] = min(full_shape[1], bbox[2])
+                    bbox[3] = min(full_shape[0], bbox[3])
+
                 # ignore invalid predictions
-                if bbox[0] > bbox[2] or bbox[1] > bbox[3] or bbox[0] < 0 or bbox[1] < 0 or bbox[2] < 0 or bbox[3] < 0:
-                    logger.warning(f"ignoring invalid prediction with bbox: {bbox}")
-                    continue
-                if full_shape is not None and (
-                    bbox[1] > full_shape[0]
-                    or bbox[3] > full_shape[0]
-                    or bbox[0] > full_shape[1]
-                    or bbox[2] > full_shape[1]
-                ):
+                if not (bbox[0] < bbox[2]) or not (bbox[1] < bbox[3]):
                     logger.warning(f"ignoring invalid prediction with bbox: {bbox}")
                     continue
 
@@ -495,3 +491,176 @@ class Yolov5DetectionModel(DetectionModel):
             object_prediction_list_per_image.append(object_prediction_list)
 
         self._object_prediction_list_per_image = object_prediction_list_per_image
+
+
+class Detectron2DetectionModel(DetectionModel):
+    def load_model(self):
+        try:
+            import detectron2
+        except ImportError:
+            raise ImportError(
+                "Please install detectron2. Check "
+                "`https://detectron2.readthedocs.io/en/latest/tutorials/install.html` "
+                "for instalattion details."
+            )
+
+        from detectron2.config import get_cfg
+        from detectron2.data import MetadataCatalog
+        from detectron2.engine import DefaultPredictor
+        from detectron2.model_zoo import model_zoo
+
+        cfg = get_cfg()
+        cfg.MODEL.DEVICE = self.device
+
+        try:  # try to load from model zoo
+            config_file = model_zoo.get_config_file(self.config_path)
+            cfg.merge_from_file(config_file)
+            cfg.MODEL.WEIGHTS = model_zoo.get_checkpoint_url(self.config_path)
+        except Exception as e:  # try to load from local
+            print(e)
+            if self.config_path is not None:
+                cfg.merge_from_file(self.config_path)
+            cfg.MODEL.WEIGHTS = self.model_path
+        # set input image size
+        if self.image_size is not None:
+            cfg.INPUT.MIN_SIZE_TEST = self.image_size
+            cfg.INPUT.MAX_SIZE_TEST = self.image_size
+        # init predictor
+        model = DefaultPredictor(cfg)
+
+        self.model = model
+
+        # detectron2 category mapping
+        if self.category_mapping is None:
+            try:  # try to parse category names from metadata
+                metadata = MetadataCatalog.get(cfg.DATASETS.TRAIN[0])
+                category_names = metadata.thing_classes
+                self.category_names = category_names
+                self.category_mapping = {
+                    str(ind): category_name for ind, category_name in enumerate(self.category_names)
+                }
+            except Exception as e:
+                logger.warning(e)
+                # https://detectron2.readthedocs.io/en/latest/tutorials/datasets.html#update-the-config-for-new-datasets
+                if cfg.MODEL.META_ARCHITECTURE == "RetinaNet":
+                    num_categories = cfg.MODEL.RETINANET.NUM_CLASSES
+                else:  # fasterrcnn/maskrcnn etc
+                    num_categories = cfg.MODEL.ROI_HEADS.NUM_CLASSES
+                self.category_names = [str(category_id) for category_id in range(num_categories)]
+                self.category_mapping = {
+                    str(ind): category_name for ind, category_name in enumerate(self.category_names)
+                }
+        else:
+            self.category_names = list(self.category_mapping.values())
+
+    def perform_inference(self, image: np.ndarray, image_size: int = None):
+        """
+        Prediction is performed using self.model and the prediction result is set to self._original_predictions.
+        Args:
+            image: np.ndarray
+                A numpy array that contains the image to be predicted. 3 channel image should be in RGB order.
+        """
+        try:
+            import detectron2
+        except ImportError:
+            raise ImportError("Please install detectron2 via `pip install detectron2`")
+
+        # confirm image_size is not provided
+        if image_size is not None:
+            warnings.warn("Set 'image_size' at DetectionModel init.")
+
+        # Confirm model is loaded
+        if self.model is None:
+            raise RuntimeError("Model is not loaded, load it by calling .load_model()")
+
+        if isinstance(image, np.ndarray) and self.model.input_format == "BGR":
+            # convert RGB image to BGR format
+            image = image[:, :, ::-1]
+
+        prediction_result = self.model(image)
+
+        self._original_predictions = prediction_result
+
+    @property
+    def num_categories(self):
+        """
+        Returns number of categories
+        """
+        num_categories = len(self.category_mapping)
+        return num_categories
+
+    def _create_object_prediction_list_from_original_predictions(
+        self,
+        shift_amount_list: Optional[List[List[int]]] = [[0, 0]],
+        full_shape_list: Optional[List[List[int]]] = None,
+    ):
+        """
+        self._original_predictions is converted to a list of prediction.ObjectPrediction and set to
+        self._object_prediction_list_per_image.
+        Args:
+            shift_amount_list: list of list
+                To shift the box and mask predictions from sliced image to full sized image, should
+                be in the form of List[[shift_x, shift_y],[shift_x, shift_y],...]
+            full_shape_list: list of list
+                Size of the full image after shifting, should be in the form of
+                List[[height, width],[height, width],...]
+        """
+        original_predictions = self._original_predictions
+
+        # compatilibty for sahi v0.8.15
+        if isinstance(shift_amount_list[0], int):
+            shift_amount_list = [shift_amount_list]
+        if full_shape_list is not None and isinstance(full_shape_list[0], int):
+            full_shape_list = [full_shape_list]
+
+        # parse boxes, masks, scores, category_ids from predictions
+        boxes = original_predictions["instances"].pred_boxes.tensor.tolist()
+        scores = original_predictions["instances"].scores.tolist()
+        category_ids = original_predictions["instances"].pred_classes.tolist()
+        try:
+            masks = original_predictions["instances"].pred_masks.tolist()
+        except AttributeError:
+            masks = None
+
+        # create object_prediction_list
+        object_prediction_list_per_image = []
+        object_prediction_list = []
+
+        # detectron2 DefaultPredictor supports single image
+        shift_amount = shift_amount_list[0]
+        full_shape = None if full_shape_list is None else full_shape_list[0]
+
+        for ind in range(len(boxes)):
+            score = scores[ind]
+            if score < self.confidence_threshold:
+                continue
+
+            category_id = category_ids[ind]
+
+            if masks is None:
+                bbox = boxes[ind]
+                mask = None
+            else:
+                mask = np.array(masks[ind])
+
+                # check if mask is valid
+                if get_bbox_from_bool_mask(mask) is not None:
+                    bbox = None
+                else:
+                    continue
+
+            object_prediction = ObjectPrediction(
+                bbox=bbox,
+                bool_mask=mask,
+                category_id=category_id,
+                category_name=self.category_mapping[str(category_id)],
+                shift_amount=shift_amount,
+                score=score,
+                full_shape=full_shape,
+            )
+            object_prediction_list.append(object_prediction)
+
+        # detectron2 DefaultPredictor supports single image
+        object_prediction_list_per_image = [object_prediction_list]
+
+        self._object_prediction_list_per_image = object_prediction_list_per_image
