@@ -27,6 +27,7 @@ from sahi.utils.file import Path, import_class, increment_path, list_files, save
 MODEL_TYPE_TO_MODEL_CLASS_NAME = {
     "mmdet": "MmdetDetectionModel",
     "yolov5": "Yolov5DetectionModel",
+    "detectron2": "Detectron2DetectionModel",
 }
 
 LOW_MODEL_CONFIDENCE = 0.1
@@ -285,7 +286,8 @@ def get_sliced_prediction(
         )
 
     # merge matching predictions
-    object_prediction_list = postprocess(object_prediction_list)
+    if len(object_prediction_list) > 0:
+        object_prediction_list = postprocess(object_prediction_list)
 
     return PredictionResult(
         image=image, object_prediction_list=object_prediction_list, durations_in_seconds=durations_in_seconds
