@@ -6,14 +6,13 @@ from sahi.slicing import slice_coco
 from sahi.utils.file import Path, get_base_filename, increment_path, save_json
 
 
-def main(
+def slice(
     image_dir: str,
     dataset_json_path: str,
     slice_size: int = 512,
     overlap_ratio: float = 0.2,
     ignore_negative_samples: bool = False,
-    project: str = "runs/slice_coco",
-    name: str = "exp",
+    output_dir: str = "runs/slice_coco",
     min_area_ratio: float = 0.1,
 ):
     """
@@ -23,8 +22,7 @@ def main(
         slice_size (int)
         overlap_ratio (float): slice overlap ratio
         ignore_negative_samples (bool): ignore images without annotation
-        project (str): save results to project/name
-        name (str): save results to project/name
+        output_dir (str): output export dir
         min_area_ratio (float): If the cropped annotation area to original
             annotation ratio is smaller than this value, the annotation
             is filtered out. Default 0.1.
@@ -32,18 +30,20 @@ def main(
 
     # assure slice_size is list
     slice_size_list = slice_size
-    if isinstance(slice_size_list, int):
+    if isinstance(slice_size_list, (int, float)):
         slice_size_list = [slice_size_list]
 
-    # set output dir
-    output_dir = Path(increment_path(Path(project) / name, exist_ok=False))  # increment run
-
     # slice coco dataset images and annotations
     print("Slicing step is starting...")
     for slice_size in slice_size_list:
-        output_images_folder_name = get_base_filename(dataset_json_path)[1] + "_sliced_images_" + str(slice_size) + "/"
-        output_images_dir = os.path.join(output_dir, output_images_folder_name)
-        sliced_coco_name = get_base_filename(dataset_json_path)[0].replace(".json", "_sliced_" + str(slice_size))
+        # in format: train_images_512_01
+        output_images_folder_name = (
+            Path(dataset_json_path).stem + f"_images_{str(slice_size)}_{str(overlap_ratio).replace('.','')}"
+        )
+        output_images_dir = str(Path(output_dir) / output_images_folder_name)
+        sliced_coco_name = Path(dataset_json_path).name.replace(
+            ".json", f"_{str(slice_size)}_{str(overlap_ratio).replace('.','')}"
+        )
         coco_dict, coco_path = slice_coco(
             coco_annotation_file_path=dataset_json_path,
             image_dir=image_dir,
@@ -64,4 +64,4 @@ def main(
 
 
 if __name__ == "__main__":
-    fire.Fire(main)
+    fire.Fire(slice)
