@@ -127,7 +127,7 @@ class CocoAnnotation:
             annotation_dict: dict
                 COCO formatted annotation dict (with fields "bbox", "segmentation", "category_id")
         """
-        if annotation_dict["segmentation"] and not isinstance(annotation_dict["segmentation"], list):
+        if annotation_dict.__contains__("segmentation") and not isinstance(annotation_dict["segmentation"], list):
             has_rle_segmentation = True
             logger.warning(
                 f"Segmentation annotation for id {annotation_dict['id']} is skipped since RLE segmentation format is not supported."
@@ -135,7 +135,11 @@ class CocoAnnotation:
         else:
             has_rle_segmentation = False
 
-        if annotation_dict["segmentation"] and not has_rle_segmentation:
+        if (
+            annotation_dict.__contains__("segmentation")
+            and annotation_dict["segmentation"]
+            and not has_rle_segmentation
+        ):
             return cls(
                 segmentation=annotation_dict["segmentation"],
                 category_id=annotation_dict["category_id"],
@@ -1694,7 +1698,7 @@ def merge(coco_dict1: dict, coco_dict2: dict, desired_name2id: dict = None) -> d
         merged_coco_dict["images"].append(image)
 
     for annotation in temp_coco_dict2["annotations"]:
-        annotation["image_id"] += max_image_id
+        annotation["image_id"] += max_image_id + 1
         annotation["id"] += max_annotation_id + 1
         merged_coco_dict["annotations"].append(annotation)
 
